@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -62,15 +62,15 @@ public:
 
     void setElement(const CBoatElement &newelement);
 
-public slots:
-    virtual void languageChange();
-
 signals:
     /** Signals that the user hit the "Remove" button. */
     void signalRemove();
     /** Signals that the element was modified. */
     void signalUpdate(const CBoatElement& newelement);
 
+private slots:
+    void languageChange();
+
 protected slots:
     void slotReload();
     void slotRemove();
@@ -118,7 +118,6 @@ public:
     void setDef(const CBoatDef &newdef);
 
 public slots:
-    virtual void languageChange();
     virtual void slotRemove();
     virtual void slotUpdate(const CBoatElement& newelement);
 
