@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 #include "sailcpp/rigworker.h"
 #include "sailwriter-xml.h"
 
+#include <QApplication>
 #include <QLayout>
 #include <QMenuBar>
 #include <QFileInfo>
@@ -32,11 +33,10 @@
 /**
  * The constructor.
  *
- * @param myPrefs the user preferences
  * @param parent the parent widget
  */
-CFormBoat::CFormBoat(CPrefs *myPrefs, QWidget *parent)
-        : CFormDocumentTmpl<CBoatDef, CBoatDefXmlWriter>(myPrefs, parent)
+CFormBoat::CFormBoat(QWidget *parent)
+    : CFormMain(parent)
 {
     // create main widget
     setupMainWidget();
@@ -45,6 +45,8 @@ CFormBoat::CFormBoat(CPrefs *myPrefs, QWidget *parent)
     setupMenuBar();
 
     // set language
+    connect(qApp, SIGNAL(languageChanged()),
+            this, SLOT(languageChange()));
     languageChange();
 
     // set initial definition
@@ -103,9 +105,28 @@ void CFormBoat::languageChange()
     setWindowTitle( tr("boat") );
     menuAdd->setTitle( tr("&Add") );
     actionAddFile->setText( tr("file") );
+}
 
-    defpanel->languageChange();
-    tabs->languageChange();
+
+bool CFormBoat::read(const QString &filename)
+{
+    try {
+        setDef(writer.read(filename));
+        return true;
+    } catch (read_error e) {
+        return false;
+    }
+}
+
+
+bool CFormBoat::write(const QString &filename)
+{
+    try {
+        writer.write(def, filename);
+        return true;
+    } catch (write_error e) {
+        return false;
+    }
 }
 
 
@@ -133,9 +154,7 @@ void CFormBoat::setupMainWidget()
     QSplitter *splitter = new QSplitter(Qt::Horizontal, this);
     splitter->addWidget(tabs);
     splitter->addWidget(defpanel);
-
-    QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->addWidget(splitter);
+    setCentralWidget(splitter);
 
     connect(defpanel, SIGNAL(signalUpdate(const CBoatDef& )), this, SLOT(slotUpdate(const CBoatDef& )));
 }
@@ -148,7 +167,7 @@ void CFormBoat::setupMenuBar()
 {
     menuAdd = new QMenu(this);
     actionAddFile = menuAdd->addAction( "", this, SLOT( slotAdd() ) );
-    extraFileMenus.push_back(menuAdd);
+    addFileMenu(menuAdd);
 }
 
 /**
@@ -157,10 +176,10 @@ void CFormBoat::setupMenuBar()
 void CFormBoat::slotAdd()
 {
     QString filter = "Sailcut CAD files (";
-    filter += QString("*") + CSailDefXmlWriter().getExtension();
-    filter += QString(" *") + CHullDefXmlWriter().getExtension();
-    filter += QString(" *") + CRigDefXmlWriter().getExtension();
-    filter += QString(" *") + CPanelGroupXmlWriter().getExtension();
+    filter += QString("*") + CSailDefXmlWriter().fileExtension();
+    filter += QString(" *") + CHullDefXmlWriter().fileExtension();
+    filter += QString(" *") + CRigDefXmlWriter().fileExtension();
+    filter += QString(" *") + CPanelGroupXmlWriter().fileExtension();
     filter += ")";
 
     QString newfile = QFileDialog::getOpenFileName(0, tr("Open"), "", filter);
