@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,33 +20,40 @@
 #ifndef FORMBOAT_H
 #define FORMBOAT_H
 
-#include "formdocument.h"
+#include "formmain.h"
 #include "sailwriter-xml.h"
 
 class CBoatDefPanel;
 
 /** A form allowing the user to assemble several elements into a boat.
  */
-class CFormBoat : public CFormDocumentTmpl<CBoatDef, CBoatDefXmlWriter>
+class CFormBoat : public CFormMain
 {
     Q_OBJECT
 
 public:
-    CFormBoat(CPrefs *myPrefs, QWidget *parent);
-    void add(const QString &newfile);
+    CFormBoat(QWidget *parent = 0);
 
 protected:
-    T_KEYPRESS
+    QString getSaveFileName(const QString &filename)
+    { return writer.getSaveFileName(filename); };
+    bool read(const QString &filename);
+    bool write(const QString &filename);
+
+private slots:
+    void languageChange();
+    void slotAdd();
+    void slotUpdate(const CBoatDef& newdef);
+
+private:
+    void add(const QString &newfile);
     void setDef(const CBoatDef &newdef);
     void setupMainWidget();
     void setupMenuBar();
 
-protected slots:
-    virtual void languageChange();
-    virtual void slotAdd();
-    virtual void slotUpdate(const CBoatDef& newdef);
+    CBoatDef def;
+    CBoatDefXmlWriter writer;
 
-protected:
     /** A panel with one tab per element in the current boat.  */
     CBoatDefPanel *defpanel;
     /** The Add menu. */
