@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,23 +24,21 @@
 /**
  * Constructs a window to display a hull.
  *
- * @param myPrefs the user preferences
  * @param parent the parent widget
  */
-CFormHull::CFormHull(CPrefs *myPrefs, QWidget *parent)
-        : CFormDocumentTmpl<CHullDef, CHullDefXmlWriter> (myPrefs, parent)
+CFormHull::CFormHull(QWidget *parent)
+    : CFormMain(parent)
 {
-    setMinimumSize( QSize( 300, 220 ) );
-
     // create menu bar
     setupMenuBar();
 
     // create main widget
-    QGridLayout *layout = new QGridLayout(this);
     tabs = new CSailViewerTabs(this);
-    layout->addWidget(tabs);
+    setCentralWidget(tabs);
 
     // set language
+    connect(qApp, SIGNAL(languageChanged()),
+            this, SLOT(languageChange()));
     languageChange();
 
     // set initial definition
@@ -56,7 +54,28 @@ void CFormHull::languageChange()
 {
     setWindowTitle( tr("hull") );
     actionViewDef->setText( tr("&Dimensions") );
-    tabs->languageChange();
+}
+
+
+bool CFormHull::read(const QString &filename)
+{
+    try {
+        setDef(writer.read(filename));
+        return true;
+    } catch (read_error e) {
+        return false;
+    }
+}
+
+
+bool CFormHull::write(const QString &filename)
+{
+    try {
+        writer.write(def, filename);
+        return true;
+    } catch (write_error e) {
+        return false;
+    }
 }
 
 
@@ -80,7 +99,7 @@ void CFormHull::setupMenuBar()
     // view actions
     actionViewDef = new QAction(this);
     connect( actionViewDef, SIGNAL( triggered() ), this, SLOT( slotDef() ) );
-    extraViewActions.push_back(actionViewDef);
+    addViewAction(actionViewDef);
 }
 
 
