@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,28 +20,35 @@
 #ifndef FORMHULL_H
 #define FORMHULL_H
 
-#include "formdocument.h"
+#include "formmain.h"
 #include "sailwriter-xml.h"
 
 /** Dialog holding a hull.
  */
-class CFormHull : public CFormDocumentTmpl<CHullDef, CHullDefXmlWriter>
+class CFormHull : public CFormMain
 {
     Q_OBJECT
 
 public:
-    CFormHull(CPrefs *myPrefs, QWidget *parent);
+    CFormHull(QWidget *parent = 0);
 
 protected:
-    T_KEYPRESS
+    QString getSaveFileName(const QString &filename)
+    { return writer.getSaveFileName(filename); };
+    bool read(const QString &filename);
+    bool write(const QString &filename);
+
+private slots:
+    void languageChange();
+    void slotDef();
+
+private:
     void setDef(const CHullDef& newdef);
     void setupMenuBar();
 
-protected slots:
-    virtual void languageChange();
-    virtual void slotDef();
+    CHullDef def;
+    CHullDefXmlWriter writer;
 
-protected:
     /** view hull definition */
     QAction *actionViewDef;
 };
