@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,19 +22,16 @@
 
 #include <QMainWindow>
 #include <QMessageBox>
-#include <QMenu>
 #include <QUrl>
-#include "formdocument.h"
+
+#include "sailviewer-tabs.h"
 
 // forward definitions
 class QAction;
-class QMdiArea;
 class QMenu;
 class QMenuBar;
 class QStatusBar;
-class QSignalMapper;
 
-class CPrefs;
 class CSailApp;
 
 
@@ -45,57 +42,42 @@ class CFormMain : public QMainWindow
     Q_OBJECT
 
 public:
-    // construction, destruction
-    CFormMain(CSailApp *myApp, QWidget *parent = 0);
-
-    void show(const QString newname = QString::null);
+    CFormMain(QWidget *parent = 0);
+    bool load(const QString &filename);
 
 protected:
-    void closeEvent( QCloseEvent * e);
-    void makeMenuMru();
-    void open(QString filename);
+    virtual QString getSaveFileName(const QString &filename) = 0;
+    virtual bool read(const QString &filename) = 0;
+    virtual bool write(const QString &filename) = 0;
+    void addFileMenu(QMenu *menu);
+    void addViewAction(QAction *action);
+    void closeEvent(QCloseEvent *e);
+
+private slots:
+    void slotAbout();
+    void slotAboutQt();
+
+    void slotOpen();
+    void slotOpenRecent();
+    void slotSave();
+    void slotSaveAs();
+
+    void slotLanguage();
+
+    void languageChange();
+    void recentDocumentsChanged();
+
+protected:
+    CSailViewerTabs *tabs;
 
 private:
-    void addChild(CFormDocument *child);
     void setupMenuBar();
-    void setupMainWidget();
-    CFormDocument *activeChild();
-
-protected slots:
-
-    virtual void languageChange();
-
-    virtual void slotAbout();
-    virtual void slotAboutQt();
-
-    virtual void slotNew();
-    virtual void slotOpen();
-    virtual void slotOpenRecent();
-    virtual void slotSave();
-    virtual void slotSaveAs();
-
-    virtual void slotHandbook();
-
-    virtual void slotLanguage();
-    virtual void slotSetActiveWindow(QWidget *widget);
-    virtual void slotUpdateDocumentMenus();
-    virtual void slotUpdateWindowMenu();
-
-protected:
-    /** The workspace */
-    QMdiArea *workspace;
-
-    /** The signal mapper */
-    QSignalMapper *windowMapper;
-
-    /** The location of the Sailcut CAD Handbook */
-    QUrl handbook;
 
     /** The application */
     CSailApp *app;
 
-    /** The user preferences */
-    CPrefs *prefs;
+    /** The current filename. */
+    QString filename;
 
     /** The status bar */
     QStatusBar* statusbar;
@@ -108,8 +90,6 @@ protected:
     QMenu *menuHelp;
     /** The View menu */
     QMenu *menuView;
-    /** The Window menu */
-    QMenu *menuWindow;
     /** The Language menu */
     QMenu *menuLanguage;
 
@@ -120,14 +100,6 @@ protected:
     QAction *actionAbout;
     /** Display information about Qt */
     QAction *actionAboutQt;
-    /** Close the active document */
-    QAction *actionClose;
-    /** Close all documents */
-    QAction *actionCloseAll;
-    /** Tile document windows */
-    QAction *actionTile;
-    /** Cascade document windows */
-    QAction *actionCascade;
 
     /** Display the handbook */
     QAction *actionHandbook;
@@ -162,11 +134,6 @@ protected:
     QAction *actionWindowSep;
     /** Quit */
     QAction *actionQuit;
-
-    /** Extra actions for the file menu */
-    vector<QAction*> childFileActions;
-    /** Extra actions for the view menu */
-    vector<QAction*> childViewActions;
 };
 
 #endif
