@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,7 @@
 #include "formpanelgroup.h"
 #include "sailtreemodel.h"
 
+#include <QApplication>
 #include <QLayout>
 #include <QSplitter>
 #include <QTreeView>
@@ -28,18 +29,17 @@
 /**
  * Constructs a window to display a collection of panels.
  *
- * @param myPrefs the user preferences
  * @param parent the parent widget
  */
-CFormPanelGroup::CFormPanelGroup(CPrefs *myPrefs, QWidget *parent)
-        : CFormDocumentTmpl<CPanelGroup, CPanelGroupXmlWriter> (myPrefs, parent)
+CFormPanelGroup::CFormPanelGroup(QWidget *parent)
+    : CFormMain(parent)
 {
-    setMinimumSize( QSize( 400, 400 ) );
-
     // create main widget
     setupMainWidget();
 
     // set language
+    connect(qApp, SIGNAL(languageChanged()),
+            this, SLOT(languageChange()));
     languageChange();
 
     // set initial definition
@@ -54,7 +54,28 @@ CFormPanelGroup::CFormPanelGroup(CPrefs *myPrefs, QWidget *parent)
 void CFormPanelGroup::languageChange()
 {
     setWindowTitle( tr("panels") );
-    tabs->languageChange();
+}
+
+
+bool CFormPanelGroup::read(const QString &filename)
+{
+    try {
+        setDef(writer.read(filename));
+        return true;
+    } catch (read_error e) {
+        return false;
+    }
+}
+
+
+bool CFormPanelGroup::write(const QString &filename)
+{
+    try {
+        writer.write(def, filename);
+        return true;
+    } catch (write_error e) {
+        return false;
+    }
 }
 
 
@@ -87,7 +108,6 @@ void CFormPanelGroup::setupMainWidget()
     splitter->addWidget(tabs);
     splitter->addWidget(treeview);
 
-    QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->addWidget(splitter);
+    setCentralWidget(splitter);
 }
 
