@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 #ifndef FORMPANELGROUP_H
 #define FORMPANELGROUP_H
 
-#include "formdocument.h"
+#include "formmain.h"
 #include "sailwriter-xml.h"
 
 // forward definitions
@@ -28,22 +28,29 @@ class QTreeView;
 
 /** Dialog holding a sail.
  */
-class CFormPanelGroup : public CFormDocumentTmpl<CPanelGroup, CPanelGroupXmlWriter>
+class CFormPanelGroup : public CFormMain
 {
     Q_OBJECT
 
 public:
-    CFormPanelGroup(CPrefs *myPrefs, QWidget *parent);
+    CFormPanelGroup(QWidget *parent = 0);
 
 protected:
-    T_KEYPRESS
+    QString getSaveFileName(const QString &filename)
+    { return writer.getSaveFileName(filename); };
+    bool read(const QString &filename);
+    bool write(const QString &filename);
+
+private slots:
+    void languageChange();
+
+private:
     void setDef(const CPanelGroup& newdef);
     void setupMainWidget();
 
-protected slots:
-    virtual void languageChange();
+    CPanelGroup def;
+    CPanelGroupXmlWriter writer;
 
-protected:
     /** the tree view */
     QTreeView *treeview;
 };
