@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,31 +20,35 @@
 #ifndef FORMRIG_H
 #define FORMRIG_H
 
-#include "formdocument.h"
+#include "formmain.h"
 #include "sailwriter-xml.h"
 
 /** Dialog holding a rig.
  */
-class CFormRig : public CFormDocumentTmpl<CRigDef, CRigDefXmlWriter>
+class CFormRig : public CFormMain
 {
     Q_OBJECT
 
 public:
-    // construction, destruction
-    CFormRig(CPrefs *myPrefs, QWidget *parent);
+    CFormRig(QWidget *parent = 0);
 
 protected:
-    T_KEYPRESS
+    QString getSaveFileName(const QString &filename)
+    { return writer.getSaveFileName(filename); };
+    bool read(const QString &filename);
+    bool write(const QString &filename);
+
+private slots:
+    void languageChange();
+    void slotDef();
+
+private:
     void setDef(const CRigDef& newdef);
     void setupMenuBar();
 
-    // slots
-protected slots:
-    virtual void languageChange();
-    virtual void slotDef();
+    CRigDef def;
+    CRigDefXmlWriter writer;
 
-    // member variables
-protected:
     /** view hull definition */
     QAction *actionViewDef;
 };
