@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -46,20 +46,20 @@ CFormRigDef::CFormRigDef( QWidget* parent, CRigDef * rigptr )
     connect( btnOK, SIGNAL( clicked() ), this, SLOT( accept() ) );
     connect( btnCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
     connect( btnCheck, SIGNAL( clicked() ), this, SLOT( slotChanged() ) );
-    connect( txt_foreI, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
-    connect( txt_foreJ, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
-    connect( txt_CSH, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
-    connect( txt_CSB, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
-    connect( txt_LSB, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
-    connect( txt_MH, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
-    connect( txt_MRnd, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
-    connect( txt_MRkM, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
-    connect( txt_MC, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
-    connect( txt_MW, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
+    connect( txt_foreI, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
+    connect( txt_foreJ, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
+    connect( txt_CSH, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
+    connect( txt_CSB, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
+    connect( txt_LSB, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
+    connect( txt_MH, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
+    connect( txt_MRnd, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
+    connect( txt_MRkM, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
+    connect( txt_MC, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
+    connect( txt_MW, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
     connect( spinBox_MRndPos, SIGNAL( valueChanged(int) ), this, SLOT( slotChanged() ) );
     connect( spinBox_SPNB, SIGNAL( valueChanged(int) ), this, SLOT( slotChanged() ) );
-    connect( txt_HAD, SIGNAL( lostFocus() ), this, SLOT( slotChanged() ) );
-    connect( txt_BAD, SIGNAL( textChanged(const QString&) ), this, SLOT( slotChanged() ) );
+    connect( txt_HAD, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
+    connect( txt_BAD, SIGNAL( textEdited(QString) ), this, SLOT( slotChanged() ) );
 
     txt_RigID->setText(QString::fromStdString(rigdef->rigID) );
     txt_foreI->setText(QString::number(rigdef->foreI) );
@@ -92,6 +92,8 @@ CFormRigDef::CFormRigDef( QWidget* parent, CRigDef * rigptr )
     txt_HAD->setText(QString::number(rigdef->HAD) );
     txt_BAD->setText(QString::number(rigdef->BAD) );
 
+    // resize
+    resize(minimumSizeHint());
 }
 
 
@@ -337,7 +339,7 @@ bool CFormRigDef::check()
     txt_MRkM->setText(QString::number(rigdef->MRakeM));
 
     /// computing mast rake in degree
-    rigdef->MRakeD = atan2(rigdef->MRakeM ,rigdef->MHeight) * (180 / PI);
+    rigdef->MRakeD = radiansToDegrees(atan2(rigdef->MRakeM ,rigdef->MHeight));
     lbl_MRkD->setText(QString::number(rigdef->MRakeD));
 
     /// computing mast base distance to stem
@@ -437,7 +439,7 @@ bool CFormRigDef::check()
     lbl_MS_TackX->setText( QString::number( int(round(rigdef->MStack.x()) ) ) );
     lbl_MS_TackY->setText( QString::number( int(rigdef->MStack.y()) ));
 
-    lbl_MS_LuffL->setText( QString::number( int(round(MSluff.norm()) ) ) );
+    lbl_MS_LuffL->setText( QString::number( int(round(MSluff.length()) ) ) );
     lbl_MS_Rake->setText( QString::number( int(round(MSluff.x()) ) ) );
 
     lbl_MS_LuffR->setText( QString::number( round(rd1) ) );
