@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 #ifndef FORMSAIL_H
 #define FORMSAIL_H
 
-#include "formdocument.h"
+#include "formmain.h"
 #include "sailwriter-xml.h"
 
 
@@ -28,47 +28,50 @@
  *
  *  @see CFormSailDef for data input and checking, CSailWorker, CSailDef
  */
-class CFormSail : public CFormDocumentTmpl<CSailDef, CSailDefXmlWriter>
+class CFormSail : public CFormMain
 {
     Q_OBJECT
 
 public:
-    // construction, destruction
-    CFormSail(CPrefs *myPrefs, QWidget *parent);
+    CFormSail(QWidget *parent = 0);
 
 protected:
-    T_KEYPRESS
+    QString getSaveFileName(const QString &filename)
+    { return writer.getSaveFileName(filename); };
+    bool read(const QString &filename);
+    bool write(const QString &filename);
+
+private slots:
+    void slotDef();
+    void slotExportDXF();
+    void slotExportDXFSplit();
+    void slotExportSVG();
+    void slotExportTXT();
+    void slotExportXML();
+    void slotExportFlatCarlson();
+    void slotExportFlatDXF();
+    void slotExportFlatDXFSplit();
+    void slotExportFlatDXFBlocks();
+    void slotExportFlatHand();
+    void slotExportFlatSVG();
+    void slotExportFlatTXT();
+    void slotExportFlatXML();
+    void slotMould();
+
+    void slotPrintData();
+    void slotPrintDwg();
+    void slotPrintDev();
+
+    void languageChange();
+
+private:
     void setDef(const CSailDef& newdef);
     void setupMenuBar();
     void setupMainWidget();
 
-    // slots
-protected slots:
+    CSailDef def;
+    CSailDefXmlWriter writer;
 
-    virtual void languageChange();
-
-    virtual void slotDef();
-    virtual void slotExportDXF();
-    virtual void slotExportDXFSplit();
-    virtual void slotExportSVG();
-    virtual void slotExportTXT();
-    virtual void slotExportXML();
-    virtual void slotExportFlatCarlson();
-    virtual void slotExportFlatDXF();
-    virtual void slotExportFlatDXFSplit();
-    virtual void slotExportFlatDXFBlocks();
-    virtual void slotExportFlatHand();
-    virtual void slotExportFlatSVG();
-    virtual void slotExportFlatTXT();
-    virtual void slotExportFlatXML();
-    virtual void slotMould();
-
-    virtual void slotPrintData();
-    virtual void slotPrintDwg();
-    virtual void slotPrintDev();
-
-    // member variables
-protected:
     /** The sail */
     CPanelGroup sail;
     /** The developed sail */
