@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -42,11 +42,11 @@ CFormSailDef::CFormSailDef( QWidget* parent, CSailDef * sailptr )
     setupUi(this);
     setModal(true);
 
-    /* we store the pointer to the CSailDef so we can update it when
-       the user clicks OK */
+    // we store the pointer to the CSailDef so we can update it when
+    // the user clicks OK
     saildef = sailptr;
 
-    /** Write all the sail data to the screen dimensions of sail. */
+    // Write all the sail data to the screen dimensions of sail.
     setSailCut( saildef->sailCut );
     setSailType( saildef->sailType );
 
@@ -94,13 +94,13 @@ CFormSailDef::CFormSailDef( QWidget* parent, CSailDef * sailptr )
 
     txtDihedral->setText ( QString::number( saildef->dihedralDeg ) );
 
-    /** Create button group for sail type. */
+    // Create button group for sail type.
     QButtonGroup *bgrpSailType = new QButtonGroup( this );
     bgrpSailType->addButton( radioMainSail );
     bgrpSailType->addButton( radioJib );
     bgrpSailType->addButton( radioWing );
 
-    /** Create button group for sail cut. */
+    // Create button group for sail cut.
     QButtonGroup *bgrpSailCut = new QButtonGroup( this );
     bgrpSailCut->addButton( radioCross );
     bgrpSailCut->addButton( radioTwist );
@@ -110,15 +110,18 @@ CFormSailDef::CFormSailDef( QWidget* parent, CSailDef * sailptr )
     bgrpSailCut->addButton( radioMitre2 );
     bgrpSailCut->addButton( radioRadial );
 
-    /** Set signals and slots connections */
+    // Set signals and slots connections
     connect( btnOK, SIGNAL( clicked() ), this, SLOT( accept() ) );
     connect( btnCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
     connect( btnCompute, SIGNAL( pressed() ), this, SLOT( slotCompute() ) );
     connect( bgrpSailType, SIGNAL( buttonClicked(QAbstractButton *) ), this, SLOT( slotSailType() ) );
     connect( bgrpSailCut, SIGNAL( buttonClicked(QAbstractButton *) ), this, SLOT( slotSailCut() ) );
 
-    /** Activate "compute" to calculate sail area and diagonal and display them. */
+    // Activate "compute" to calculate sail area and diagonal and display them.
     compute();
+
+    // resize
+    resize(minimumSizeHint());
 }
 
 
@@ -325,7 +328,7 @@ bool CFormSailDef::check()
     /** Create four palettes for levels of warning. */
     QPalette palStd, palHi, palLo, palRel;
     palStd = txtLuffLen->palette();
-    palLo = palHi = palRel = palStd;
+    palLo = palHi = palRel = palStd;   // normal value
     palLo.setColor( QPalette::Text, Qt::magenta); // too low value
     palHi.setColor( QPalette::Text, Qt::red );    // too high value
     palRel.setColor( QPalette::Text, Qt::blue );  // related value to be checked
@@ -475,7 +478,7 @@ bool CFormSailDef::check()
     saildef->footR  = txtFootRound->text().toDouble();
     saildef->footRP = 50; // imposed value
 
-    /** Check  rake. */
+    /** Check luff rake. */
     saildef->rake   = txtRake->text().toDouble();
 
     switch (saildef->sailType )
@@ -526,12 +529,13 @@ bool CFormSailDef::check()
         break;
     }
 
-    /** Check luff length and round, gaff length. */
+    /** Check luff length and round, gaff length */
     L1 = (long)(saildef->LOA);
 
     switch (saildef->sailType )
     {
     case MAINSAIL:
+        /** Check luff against fore triangle */
         L1 = (long) (saildef->foreI);
         if (saildef->luffL > 3*L1)
         {
@@ -554,6 +558,7 @@ bool CFormSailDef::check()
         }
         txtLuffLen->setText(QString::number(saildef->luffL));
 
+        /** check luff round against luff length */
         L2 =(long) ((saildef->luffL ) / 10); // luff round limit
 
         if (saildef->luffR > L2)
@@ -574,9 +579,29 @@ bool CFormSailDef::check()
         }
         txtLuffRound->setText(QString::number(saildef->luffR) );
 
-        /** Check main sail gaff length. */
+        /** check main sail foot length against Luff*/
+        L2 = (long)(saildef->luffL);
+        if (saildef->footL > L2)
+        {
+            flag = false;
+            saildef->footL = L2;
+            txtFootLen->setPalette(palHi);
+        }
+        else if (saildef->footL < int(L2/10))
+        {
+            flag = false;
+            saildef->footL = 1+ int(L2/10);
+            txtFootLen->setPalette(palLo);
+        }
+        else
+        {
+            txtFootLen->setPalette(palStd);
+        }
+        txtFootLen->setText(QString::number(saildef->footL));
+
+        /** Check main sail gaff length against foot */
         L1 =(long) (5);
-        L2 =(long) (6 * saildef->luffL);
+        L2 =(long) (saildef->footL);
 
         if (saildef->gaffL < L1)
         {
@@ -620,6 +645,7 @@ bool CFormSailDef::check()
         break;
 
     case JIB:
+        /** check luff against fore triangle */
         L1 =( long) (sqrt(((saildef->foreI - saildef->tackY) * (saildef->foreI - saildef->tackY)) + (saildef->foreJ * saildef->foreJ ))-1);
         if (saildef->luffL > L1)
         {
@@ -644,20 +670,20 @@ bool CFormSailDef::check()
         txtLuffLen->setText(QString::number(saildef->luffL) );
 
         L2 = (long) ((saildef->luffL )/ 10); // round limit
-        /** To acommodate code zero jib
+        /** To accommodate code zero jib
             the positive luff round limit is twice negative round limit
         */
         if (saildef->luffR > 2*L2)
         {
             flag=false;
             txtLuffRound->setPalette(palHi);
-            saildef->luffR = 2*L2;
+            saildef->luffR = 2*L2-1;
         }
         else if (saildef->luffR <-L2)
         {
             flag=false;
             txtLuffRound->setPalette(palLo);
-            saildef->luffR = -L2;
+            saildef->luffR = -L2+1;
         }
         else
         {
@@ -702,12 +728,12 @@ bool CFormSailDef::check()
 
         // check gaff angle and set it to be horizontal
         A1 = saildef->rake / saildef->luffL;
-        saildef->gaffDeg = acos (A1) * 180/PI;
+        saildef->gaffDeg = radiansToDegrees(acos(A1));
         txtGaffAngle->setText(QString::number(floor(saildef->gaffDeg)) );
 
         // adjust leech length such that foot is horizontal
         A1 = saildef->rake + saildef->gaffL - saildef->footL;
-        A2 = saildef->luffL * sin(saildef->gaffDeg * PI/180);
+        A2 = saildef->luffL * sin(degreesToRadians(saildef->gaffDeg));
 
         saildef->leechL = floor(sqrt( A1*A1 + A2*A2 ) );
         txtLeechLen->setText(QString::number(saildef->leechL) );
@@ -736,22 +762,34 @@ bool CFormSailDef::check()
     }
 
     /** Check leech length. */
-    L1 = (long) saildef->luffL;
-    L1 = L1 + (long) saildef->gaffL;
+    L1 = (long) saildef->luffL + (long) saildef->gaffL;
+    L2 = (long) (int(0.5 * saildef->footL));
 
-    if (saildef->leechL > 1.5*L1)
+    if (saildef->leechL > L1+L2)
+    {
+        flag = false;
+        txtLuffLen->setPalette(palLo);
+        txtGaffLen->setPalette(palLo);
+        txtFootLen->setPalette(palLo);
+        txtLeechLen->setPalette(palHi);
+        saildef->leechL = L1+L2;
+    }
+    /** leech old check
+    else if (saildef->leechL > 1.5*L1)
     {
         flag = false;
         txtLuffLen->setPalette(palRel);
         txtLeechLen->setPalette(palHi);
         saildef->leechL = 1.5*L1 -1;
     }
-    else if (saildef->leechL < 0.5*L1)
+    */
+
+    else if (saildef->leechL < int(0.5*L1))
     {
         flag = false;
         txtLuffLen->setPalette(palRel);
         txtLeechLen->setPalette(palLo);
-        saildef->leechL = 0.5*L1 +1;
+        saildef->leechL = 1+ int(0.5*L1);
     }
     else
     {
@@ -761,14 +799,22 @@ bool CFormSailDef::check()
     txtLeechLen->setText(QString::number(saildef->leechL));
 
     /** Check leech round. */
-    L1 = (long) (saildef->leechL / 10);
+    L1 = (long) int(saildef->leechL / 10);
+    L2 = (long) int(saildef->footL /5);
     if (saildef->leechR > 3*L1)
     {
         flag = false;
         txtLeechRound->setPalette(palHi);
         txtLeechRound->setText(QString::number(3*L1) );
     }
-    else if (saildef->leechR <-L1)
+    else if (saildef->leechR <-L2)
+    {
+        flag = false;
+        txtLeechRound->setPalette(palLo);
+        txtLeechRound->setText(QString::number(1-L2) );
+    }
+
+    if (saildef->leechR <-L1)
     {
         flag = false;
         txtLeechRound->setPalette(palLo);
@@ -783,36 +829,38 @@ bool CFormSailDef::check()
     case MAINSAIL:
         L2 = (long)(saildef->luffL + saildef->gaffL - saildef->leechL);
         if (L2 < (long)(0.1*(saildef->luffL)))
-            L2=(long)(0.1*(saildef->luffL));
+            L2=(long)(1+ 0.1*(saildef->luffL));
         break;
     case JIB:
         L2 = (long)(saildef->luffL  - saildef->leechL);
         if (L2 < (long)(0.1*(saildef->luffL)))
-            L2=(long)(0.1*(saildef->luffL));
+            L2=(long)(1 +0.1*(saildef->luffL));
         break;
     case WING:
         L2 = (long)(saildef->luffL  - saildef->leechL);
         if (L2 < (long)(0.1*(saildef->luffL)))
-            L2=(long)(0.1*(saildef->luffL));
+            L2=(long)(1+0.1*(saildef->luffL));
         break;
     }
 
-    if (saildef->footL > 1.5*(saildef->leechL) )
+    if (saildef->footL > saildef->leechL)
     {
         flag=false;
         txtLeechLen->setPalette( palRel );
         txtFootLen->setPalette( palHi );
-        saildef->footL = 1.5*(saildef->leechL) -1;
+        saildef->footL = (saildef->leechL) -1;
     }
     else if (saildef->footL < L2)
     {
         flag=false;
-        txtLeechLen->setPalette( palRel );
+        txtLuffLen->setPalette( palRel );
+        txtLeechLen->setPalette( palHi );
         txtFootLen->setPalette( palLo );
         saildef->footL = L2 +1;
     }
     else
     {
+        txtLuffLen->setPalette( palStd );
         txtLeechLen->setPalette( palStd );
         txtFootLen->setPalette( palStd );
     }
@@ -860,23 +908,26 @@ bool CFormSailDef::check()
     saildef->footHemW = txtFootHemWidth->text().toDouble();
     saildef->hemsW = txtHemsWidth->text().toDouble();
 
-    /** Check cloth width. */
-    if (saildef->clothW < saildef->leechL /100)
+    /** Check cloth width against Leech length to ensure min/max number of panels. */
+    if (saildef->clothW < saildef->leechL /100) // max 100 panels
     {
-        saildef->clothW = saildef->leechL /100 +1;
+        saildef->clothW = 1+ int(saildef->leechL /100);
         flag = false;
         txtClothWidth->setPalette(palLo);
     }
-    else if (saildef->clothW > saildef->leechL /3)
+    else if (saildef->clothW > saildef->leechL /3) // min 3 panels
     {
-        saildef->clothW = saildef->leechL /3;
+        saildef->clothW = int(saildef->leechL /3 -1);
         flag = false;
         txtClothWidth->setPalette(palHi);
     }
-
+    else
+    {
+        txtClothWidth->setPalette(palStd);
+    }
     txtClothWidth->setText( QString::number(saildef->clothW));
 
-    L1 = (long)(5+ saildef->clothW / 10);
+    L1 = (long)(5+ int(saildef->clothW / 10));
 
     /** Check seams width function of cloth width. */
     if (saildef->seamW > L1)
@@ -1122,7 +1173,6 @@ void CFormSailDef::slotSailCut()
 }
 
 
-
 /**
  *  Saves the parameters entered by the user in the CSailDef.
  *  compute and display ancillary sail data
@@ -1131,22 +1181,25 @@ void CFormSailDef::slotSailCut()
  */
 void CFormSailDef::slotCompute()
 {
-    // ckeck data
-    check();
-    // calculate sail area and diagonal
-    compute();
-
-    // display ancillary data
     real h=0, w=0, w1=0;
     QString txta, txtb, txtc, txtd, txte;
 
+    // warning if flag returned from check is NOK
+    if (check())
+        txte = "\n Dimensions OK";
+    else
+        txte = "\n SOME DIMENSIONS ARE OUT OF LIMITS, PLEASE FIX THEM";
+
+    // calculate sail area and diagonal
+    compute();
+
     CSailWorker worker(*saildef);
 
     txta = tr("Sail corners coordinates");
-    txta = txta+"\n  "+tr("tack")+" \t x = "+QString::number(int(worker.tack.x())) +"\n\t y = "+QString::number(int(worker.tack.y())) +" mm" ;
+    txta = txta+"\n  "+tr("tack")+" \t x = "+QString::number(int(worker.tack.x())) +"\n\t y = "+QString::number(int(worker.tack.y())) +" mm";
     txta = txta+"\n  "+tr("clew")+" \t x = "+QString::number(int(worker.clew.x())) +"\n\t y = "+QString::number(int(worker.clew.y())) +" mm";
     txta = txta+"\n  "+tr("head")+" \t x = "+QString::number(int(worker.head.x())) +"\n\t y = "+QString::number(int(worker.head.y())) +" mm";
-    txta = txta+"\n  "+tr("peak")+" \t x = "+QString::number(int(worker.peak.x())) +"\n\t y = "+QString::number(int(worker.peak.y())) +" mm ";
+    txta = txta+"\n  "+tr("peak")+" \t x = "+QString::number(int(worker.peak.x())) +"\n\t y = "+QString::number(int(worker.peak.y())) +" mm";
 
     w = worker.SailLP();
     txtb = "\nLP = " +QString::number(int(w)) +" mm ";
