@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,8 +27,11 @@
  *
  * @relates SailCpp
  */
-#include <geocpp/geometry.h>
 #include <geocpp/matrix.h>
+#include <geocpp/matrix4x4.h>
+#include <geocpp/rect.h>
 #include <geocpp/subspace.h>
 
+using namespace std;
+
 #endif
