@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,6 @@
  */
 
 #include <geocpp/matrix.h>
-#include <geocpp/subspace.h>
 
 #include <climits>
 #include <cmath>
@@ -92,12 +91,12 @@ CMatrix CMatrix::rot3d(const size_t& axis, const real& angle)
  *
  * @param index the index of the column to return
  */
-CVector CMatrix::col(const size_t& index) const
+std::vector<real> CMatrix::col(size_t index) const
 {
     if (index >= m_ncol)
-        throw range_error("CMatrix::col : index out of bounds!");
+        throw std::range_error("CMatrix::col : index out of bounds!");
 
-    CVector ret(m_nrow);
+    std::vector<real> ret(m_nrow);
     for (size_t i = 0; i < m_nrow; i++)
         ret[i] = m_data[i*m_ncol + index];
     return ret;
@@ -137,10 +136,10 @@ CMatrix CMatrix::crop(const size_t& nr,
 
 /** Returns the determinant of a CMatrix. The matrix must be square!
  */
-real CMatrix::det(void) const
+real CMatrix::determinant() const
 {
     if (m_nrow != m_ncol)
-        throw invalid_argument("CMatrix::det : matrix is not square!");
+        throw std::invalid_argument("CMatrix::det : matrix is not square!");
 
     real ret=0;
     // if we have a scalar matrix return its only coefficient
@@ -151,9 +150,9 @@ real CMatrix::det(void) const
     for (size_t j=0; j < m_ncol; j++)
     {
         if (j%2)
-            ret -= (*this)(0,j) * dev(0,j).det();
+            ret -= (*this)(0,j) * dev(0,j).determinant();
         else
-            ret += (*this)(0,j) * dev(0,j).det();
+            ret += (*this)(0,j) * dev(0,j).determinant();
     }
     return ret;
 }
@@ -168,10 +167,10 @@ real CMatrix::det(void) const
 CMatrix CMatrix::dev(const size_t& i, const size_t& j) const
 {
     if ((i >= m_nrow) || (j >= m_ncol))
-        throw range_error("CMatrix::dev : index out of bounds");
+        throw std::range_error("CMatrix::dev : index out of bounds");
 
     if (m_nrow != m_ncol)
-        throw invalid_argument("CMatrix::dev : matrix is not square!");
+        throw std::invalid_argument("CMatrix::dev : matrix is not square!");
 
     size_t dx=0,dy=0;
 
@@ -202,20 +201,16 @@ CMatrix CMatrix::dev(const size_t& i, const size_t& j) const
 /** Diagonalises matrix by Gauss-Jordan method with full pivoting
  * optionally returns the inverse matrix.
  */
-CMatrix CMatrix::gaussjordan(bool *is_inv, CMatrix *inv, soltype_t * soltype, CVector *bb, CMatrix *tkern) const
+CMatrix CMatrix::gaussjordan(bool *is_inv, CMatrix *inv, soltype_t * soltype, std::vector<real> *bb, CMatrix *tkern) const
 {
     // check dimensions
-    CMatrix b;
-    if (bb!=NULL)
-    {
+    CMatrix b(m_nrow, 1);
+    if (bb != NULL) {
         if (bb->size() != m_nrow)
-            throw invalid_argument("CMatrix::solve : matrix <=> right-hand side dimensions incompatible");
+            throw std::invalid_argument("CMatrix::solve : matrix <=> right-hand side dimensions incompatible");
 
-        b = *bb;
-    }
-    else
-    {
-        b = CMatrix(m_nrow, 1);
+        for (size_t i = 0; i < m_nrow; ++i)
+            b(i, 0) = (*bb)[i];
     }
     //cout << "b" << endl<< b << endl;
     //cout << "m" << endl<< *this << endl;
@@ -265,7 +260,7 @@ CMatrix CMatrix::gaussjordan(bool *is_inv, CMatrix *inv, soltype_t * soltype, CV
             }
         }
         // if pivot is smaller than epsillon we cannot continue diagonalisation
-        if ( p_avalue < EPS )
+        if ( p_avalue <= EPS )
             break;
 
         // exchange rows k and p_i
@@ -324,7 +319,7 @@ CMatrix CMatrix::gaussjordan(bool *is_inv, CMatrix *inv, soltype_t * soltype, CV
         if (*soltype==NONE)
         {
             // incompatible system
-            *bb = CVector(0);
+            *bb = std::vector<real>(0);
         }
         else
         {
@@ -376,7 +371,7 @@ CMatrix CMatrix::gaussjordan(bool *is_inv, CMatrix *inv, soltype_t * soltype, CV
 
     for (i = 0; i < m_nrow; i++)
         for (j = 0; j < m_ncol; j++)
-            if (fabs(m(i,j)) < EPS)
+            if (fabs(m(i,j)) <= EPS)
                 m(i,j) = 0;
 
     //  return m;
@@ -385,36 +380,6 @@ CMatrix CMatrix::gaussjordan(bool *is_inv, CMatrix *inv, soltype_t * soltype, CV
 }
 
 
-/** Returns the image space of the linear application
- *  associated with the matrix.
- */
-CMatrix CMatrix::img(void) const
-{
-    return transp().diag().transp();
-}
-
-
-/** Inverts matrix by Gauss-Jordan method with full pivoting.
- */
-CMatrix CMatrix::inv(void) const
-{
-    if (m_nrow != m_ncol)
-        throw invalid_argument("CMatrix:: inv : matrix is not square !");
-
-    // if matrix is empty, return empy matrix
-    if (empty())
-        return CMatrix();
-
-    CMatrix ret;
-    bool is_inv;
-    gaussjordan(&is_inv,&ret);
-    if (is_inv == false)
-        throw invalid_argument("CMatrix::diag : matrix is singular !");
-
-    return ret;
-}
-
-
 /** Returns the kernel of the linear application.
  *  associated with the matrix.
  */
@@ -422,7 +387,7 @@ CMatrix CMatrix::kern(const size_t& vsize) const
 {
     if (empty())
     {
-        cout << "REQUEST FOR KER(o)" << endl;
+        std::cout << "REQUEST FOR KER(o)" << std::endl;
         return CMatrix::id(vsize);
     }
 
@@ -434,62 +399,24 @@ CMatrix CMatrix::kern(const size_t& vsize) const
 
 /** Retrieves a row of the matrix in vector form.
  */
-CVector CMatrix::row(size_t index) const
+std::vector<real> CMatrix::row(size_t index) const
 {
     if (index >= m_nrow)
-        throw range_error("CMatrix::row : index out of bounds!");
+        throw std::range_error("CMatrix::row : index out of bounds!");
 
-    CVector ret(m_ncol);
+    std::vector<real> ret(m_ncol);
     for (size_t i = 0; i < m_ncol; i++)
         ret[i] = m_data[index*m_ncol + i];
     return ret;
 }
 
 
-/** Solves the linear equations system formed by the current matrix
- * and a given right-hand side vector.
- *
- * @param b the right-hand side values in the equation
- */
-CSubSpace CMatrix::solve(const CVector &b) const
-{
-    if (m_nrow != b.size())
-        throw invalid_argument("CMatrix::solve : dimension mismatch");
-
-    //cout << "[[ solver ]]" << endl;
-    //cout << "m" << endl << *this << endl;
-    //cout << "b" << endl << b << endl;
-
-    soltype_t soltype=NONE;
-    CVector s = b;
-    CMatrix k;
-    CSubSpace h(CVector(0),CMatrix());
-
-    gaussjordan(NULL,NULL,&soltype,&s,&k);
-    switch (soltype)
-    {
-    case NONE:
-        //cout << "CMatrix::solve : system has no solution" << endl;
-        break;
-    case ONE:
-        //cout << "CMatrix::solve : system has unique solution" << endl;
-        h = CSubSpace(s,CMatrix::id(s.size()));
-        break;
-    case INF:
-        //cout << "CMatrix::solve : system has an infinity of solutions" << endl;
-        h = CSubSpace(s,k,GEOCPP_FROM_BASE);
-        break;
-    }
-    return h;
-}
-
-
 /** Swaps two rows of a matrix.
  */
-void CMatrix::swap_row(const size_t& i1, const size_t& i2)
+void CMatrix::swap_row(size_t i1, size_t i2)
 {
     if ((i1>=m_nrow)||(i2>=m_nrow))
-        throw range_error("CMatrix:swap_row : index out of bounds");
+        throw std::range_error("CMatrix:swap_row : index out of bounds");
 
     if (i1==i2)
         return;
@@ -508,10 +435,10 @@ void CMatrix::swap_row(const size_t& i1, const size_t& i2)
 
 /** Swap two columns of a matrix.
  */
-void CMatrix::swap_col(const size_t& j1, const size_t& j2)
+void CMatrix::swap_col(size_t j1, size_t j2)
 {
     if ((j1>=m_ncol)||(j2>=m_ncol))
-        throw range_error("CMatrix:swap_col : index out of bounds");
+        throw std::range_error("CMatrix:swap_col : index out of bounds");
 
     if (j1==j2)
         return;
@@ -530,7 +457,7 @@ void CMatrix::swap_col(const size_t& j1, const size_t& j2)
 
 /** Transposes ('tilts') matrix
  */
-CMatrix CMatrix::transp(void) const
+CMatrix CMatrix::transposed() const
 {
     CMatrix ret(m_ncol,m_nrow);
 
@@ -616,7 +543,7 @@ CMatrix CMatrix::operator-() const
 CMatrix CMatrix::operator*(const CMatrix &m2) const
 {
     if (m_ncol != m2.m_nrow)
-        throw invalid_argument("CMatrix::operator*: dimension mismatch!");
+        throw std::invalid_argument("CMatrix::operator*: dimension mismatch!");
 
     CMatrix p(m_nrow, m2.m_ncol);
     size_t pos = 0;
@@ -635,13 +562,13 @@ CMatrix CMatrix::operator*(const CMatrix &m2) const
 
 /** Multiplies a matrix by a vector.
  */
-CVector CMatrix::operator*(const CVector &v) const
+std::vector<real> CMatrix::operator*(const std::vector<real> &v) const
 {
     if (m_ncol != v.size())
-        throw invalid_argument("CMatrix::operator*: dimension mismatch!");
+        throw std::invalid_argument("CMatrix::operator*: dimension mismatch!");
 
     // result is initialised to zero
-    CVector p(m_nrow);
+    std::vector<real> p(m_nrow);
     size_t pos = 0;
     for (size_t i = 0; i < m_nrow; i++)
     {
