@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,28 +31,16 @@ enum subspaceflags_t { GEOCPP_FROM_BASE, GEOCPP_FROM_EQS };
  */
 class CSubSpace
 {
-private:
-    CMatrix m;
-    CVector p;
 public:
-    CSubSpace(size_t dim_space = 3, size_t dim_sub = 0);
-    CSubSpace(const CVector &pi, const CMatrix &mi, subspaceflags_t createflags = GEOCPP_FROM_EQS);
+    CSubSpace();
+    CSubSpace(const CVector3d &pi, const CMatrix &mi, subspaceflags_t createflags);
+    CSubSpace(const CSubSpace &s);
 
-    /** Copy constructor */
-    CSubSpace(const CSubSpace &s) : m(s.m) , p(s.p)
-    {}
-    ;
     CSubSpace intersect(const CSubSpace &) const;
-    bool contains(const CVector &) const;
+    CVector3d intersectionPoint(const CSubSpace &, const std::string &name) const;
 
-    /** Return the subspace's dimension. */
-    int getdim() const
-    {
-        if (p.size() > 0)
-            return p.size() - m.rows();
-        else
-            return -1;
-    }
+    bool contains(const CVector3d &) const;
+    int getdim() const;
 
     /** Accessor for the matrix. */
     const CMatrix& getm() const
@@ -61,13 +49,18 @@ public:
     }
 
     /** Accessor for the point. */
-    const CVector& getp() const
+    const CVector3d& getp() const
     {
         return p;
     }
+
+    static CSubSpace line(const CPoint3d& p, const CVector3d& v);
+    static CSubSpace plane(const CPoint3d& p, const CVector3d& v1, const CVector3d& v2);
+
+private:
+    bool isEmpty;
+    CMatrix m;
+    CVector3d p;
 };
 
-// global functions
-ostream& operator<< (ostream &, const CSubSpace &);
-
 #endif
