@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,11 +17,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <cstdio>
-#include <iostream>
-
-#include "sailcutqt.h"
-#include "formmain.h"
+#include "app.h"
 
 /** @mainpage
  * This is the documentation for Sailcut CAD's code.
@@ -41,12 +37,11 @@ int main( int argc, char* argv[] )
     CSailApp app( argc, argv );
     app.readPrefs();
 
-    CFormMain *sailcut = new CFormMain(&app);
-
-    if (argc > 1)
-        sailcut->show(argv[1]);
-    else
-        sailcut->show();
+    if (argc > 1) {
+        app.open(argv[1]);
+    } else {
+        app.createSail();
+    }
 
     retCode = app.exec();
     app.writePrefs();
