@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,21 +25,6 @@
 
 using namespace std;
 
-/**
- * A list of most recently used (MRU) files.
- */
-class CPrefsMru : public vector<QString>
-{
-public:
-    /** Construct a new list of Most Recently Used (MRU) files. */
-    CPrefsMru()
-    {}
-    ;
-    void touchEntry(const QString& newentry);
-    void removeEntry(const QString& oldentry);
-};
-
-
 /**
  * A class used to store a user's preferences.
  */
@@ -49,12 +34,7 @@ public:
     CPrefs();
 
     /** The most recently used documents. */
-    CPrefsMru mruDocuments;
-
-    /** The width of the help window */
-    int helpWindowWidth;
-    /** The height of the help window */
-    int helpWindowHeight;
+    vector<QString> mruDocuments;
 
     /** The width of the main window */
     int mainWindowWidth;
