@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,8 +31,11 @@ CPanelGroup CBoatDef::makePanelGroup() const
 {
     CPanelGroup output;
 
-    for (unsigned int i = 0; i < size(); i++)
-        output.child.push_back(at(i) + at(i).origin);
+    for (unsigned int i = 0; i < size(); i++) {
+        CMatrix4x4 matrix;
+        matrix.translate(at(i).origin);
+        output.child.push_back(at(i).transformed(matrix));
+    }
 
     return output;
 }
