@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -39,41 +39,36 @@ CHullWorker::CHullWorker(const CHullDef &d) : CHullDef(d)
     /** compute the vertical central plane */
     CVector3d v1 = CVector3d( 1 , 0 , 0 );
     CVector3d v2 = CVector3d( 0 , 1 , 0 );
-    planeCentral = CSubSpace3d::plane( ptFwdChine , v1 , v2 );
+    planeCentral = CSubSpace::plane( ptFwdChine , v1 , v2 );
 
     /** compute the lower Chine plane */
     // vector v1 is sideway tilt of chine
-    v1 = CVector3d( 0 , -sin(real(BSlopeA)*PI/180) , cos(real(BSlopeA)*PI/180) );
+    v1 = CVector3d( 0 , -sin(degreesToRadians(BSlopeA)) , cos(degreesToRadians(BSlopeA)) );
     // vector v2 is fore-aft slope of chine
     v2 = CVector3d( ptAftChine - ptFwdChine );
-    planeLowChine = CSubSpace3d::plane( ptFwdChine , v1 , v2 );
+    planeLowChine = CSubSpace::plane( ptFwdChine , v1 , v2 );
 
     /** compute the Deck plane */
     // vector v1 is sideway tilt of deck
-    v1 = CVector3d( 0 , -sin(real(DSlopeA)*PI/180) , cos(real(DSlopeA)*PI/180) );
+    v1 = CVector3d( 0 , -sin(degreesToRadians(DSlopeA)) , cos(degreesToRadians(DSlopeA)) );
     // vector v2 is fore-aft slope of deck
     v2 = CVector3d( BLWL , DaftHeight-DfwdHeight , 0 );
-    planeDeck = CSubSpace3d::plane( ptFwdDeck , v1 , v2 );
+    planeDeck = CSubSpace::plane( ptFwdDeck , v1 , v2 );
 
     /** compute the transom plane */
     // vector v1 is parallel to Z axis = perpendicular to central plane
     v1 = CVector3d( 0 , 0 , 1 );
     // vector v2 is in inclined transom plane
-    v2 = CVector3d( cos(real(TransomA) * PI/180) , sin(real(TransomA) * PI/180) , 0 );
-    planeTransom = CSubSpace3d::plane( ptAftChine , v1 , v2 );
+    v2 = CVector3d( cos(degreesToRadians(TransomA)) , sin(degreesToRadians(TransomA)) , 0 );
+    planeTransom = CSubSpace::plane( ptAftChine , v1 , v2 );
 
     // compute intersection line between lower chine plane and transom
     CSubSpace Line1 = planeLowChine.intersect(planeTransom);
+    if (Line1.getdim() != 1)
+        throw "ERROR in hullworker constructor = intersection chine plane and transom is not a line";
 
     // compute intersection point of line1 with central plane located at aft width
-    if (Line1.getdim() == 1)
-    {
-        CSubSpace Intersection2 = Line1.intersect(planeCentral);
-        if (Intersection2.getdim() == 0)
-            ptCentreChine = Intersection2.getp();
-        else throw "ERROR in hullworker constructor = no low chine aft  point";
-    }
-    else throw "ERROR in hullworker constructor = intersection chine plane and transom is not a line";
+    ptCentreChine = Line1.intersectionPoint(planeCentral, "low chine aft");
 
     /** lay lower chine plane decking panel */
     unsigned int j;
@@ -119,15 +114,7 @@ CPoint3d CHullWorker::ptLowChine( const real &x )
     CPoint3d pt = CPoint3d ( x , y , z );
 
     /* compute y by projecting pt vertically on the chine plane */
-
-    CSubSpace Intersection1 = planeLowChine.intersect(CSubSpace3d::line(pt, CVector3d(0, 1, 0) ) );
-
-    if (Intersection1.getdim() == 0 )
-        pt = Intersection1.getp();
-    else
-        throw "ERROR in CHullWorker::ptLowChine intersection is not a point";
-
-    return pt;
+    return planeLowChine.intersectionPoint(CSubSpace::line(pt, CVector3d(0, 1, 0)), "low chine");
 }
 
 
@@ -144,19 +131,11 @@ CPoint3d CHullWorker::ptKeel( const real &x )
     pt = ptLowChine ( x );
 
     /* Ruling vector with deadrise and sweep. */
-    v1 = CVector3d( tan( real(BSweepA) * PI/180) , tan( real(BDeadriseA) * PI/180) , 1 );
+    v1 = CVector3d( tan(degreesToRadians(BSweepA)) , tan(degreesToRadians(BDeadriseA)) , 1 );
 
     /* Project pt on central plane, get intersection
        with the ruling line passing through point pt. */
-    CSubSpace Intersection1 = planeCentral.intersect(
-        CSubSpace3d::line(pt, v1));
-
-    if (Intersection1.getdim() == 0 )
-        pt = Intersection1.getp();
-    else
-        throw "ERROR in CHullWorker::ptKeel intersection is not a point";
-
-    return pt;
+    return planeCentral.intersectionPoint(CSubSpace::line(pt, v1), "keel");
 }
 
 
@@ -200,32 +179,27 @@ CPanelGroup CHullWorker::makeHull() //const
     plank2 = plank1;
     for (j = 0 ; j < npb ; j++)
     {   // mirror points
-        plank2.top[j].z() = -plank1.top[j].z();
-        plank2.bottom[j].z() = -plank1.bottom[j].z();
+        plank2.top[j].setZ(-plank1.top[j].z());
+        plank2.bottom[j].setZ(-plank1.bottom[j].z());
     }
     for (j = 0 ; j < npl ; j++)
     {   // mirror points
-        plank2.left[j].z() = -plank1.left[j].z();
-        plank2.right[j].z() = -plank1.right[j].z();
+        plank2.left[j].setZ(-plank1.left[j].z());
+        plank2.right[j].setZ(-plank1.right[j].z());
     }
     // add the bottom planks to the hull
     hull.push_back(plank1);
     hull.push_back(plank2);
 
     /** Lay a single top side plank on each side with bottom at chine */
-    v1 = CVector3d( -cos(real(StemA) * PI/180) , sin(real(TopPlankA) * PI/180) , cos(real(TopPlankA) * PI/180) );
+    v1 = CVector3d( -cos(degreesToRadians(StemA)) , sin(degreesToRadians(TopPlankA)) , cos(degreesToRadians(TopPlankA)) );
 
     for (j = 0 ; j < npb ; j++)
     {
         plank1.bottom[j] =  chine.bottom[j];
-        CSubSpace Intersection1 = planeDeck.intersect(
-            CSubSpace3d::line(plank1.bottom[j], v1));
-        if (Intersection1.getdim() == 0)
-        {   // compute the vector vg which generate the side surface
-            p1 = Intersection1.getp();
-            vg = CVector3d(p1 - pt);
-        }
-        else throw "ERROR in CHullWorker::makeHull() Intersection 1 top side is not a point" ;
+        p1 = planeDeck.intersectionPoint(CSubSpace::line(plank1.bottom[j], v1), "top side");
+        // compute the vector vg which generate the side surface
+        vg = CVector3d(p1 - pt);
         plank1.top[j] = p1;
     }
     plank1.left.fill( plank1.bottom[0] , plank1.top[0] );
@@ -234,13 +208,13 @@ CPanelGroup CHullWorker::makeHull() //const
     plank2 = plank1;
     for (j = 0 ; j < npb ; j++)
     {   // mirror points
-        plank2.top[j].z() = -plank1.top[j].z();
-        plank2.bottom[j].z() = -plank1.bottom[j].z();
+        plank2.top[j].setZ(-plank1.top[j].z());
+        plank2.bottom[j].setZ(-plank1.bottom[j].z());
     }
     for (j = 0 ; j < npl ; j++)
     {   // mirror points
-        plank2.left[j].z() = -plank1.left[j].z();
-        plank2.right[j].z() = -plank1.right[j].z();
+        plank2.left[j].setZ(-plank1.left[j].z());
+        plank2.right[j].setZ(-plank1.right[j].z());
     }
     // add the top side planks to the hull
     hull.push_back(plank1);
@@ -251,13 +225,13 @@ CPanelGroup CHullWorker::makeHull() //const
     {
         deck1.bottom[j] = plank1.top[j];
         deck1.top[j] = deck1.bottom[j];
-        deck1.top[j].z() = 0;
+        deck1.top[j].setZ(0);
         deck1.left.fill(deck1.bottom[0] , deck1.top[0]);
         deck1.right.fill(deck1.bottom[npb-1] , deck1.top[npb-1]);
 
         deck2.bottom[j] = plank2.top[j];
         deck2.top[j] = deck2.bottom[j];
-        deck2.top[j].z() = 0;
+        deck2.top[j].setZ(0);
         deck2.left.fill(deck2.bottom[0] , deck2.top[0]);
         deck2.right.fill(deck2.bottom[npb-1] , deck2.top[npb-1]);
     }
