@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,8 @@
 #ifndef PANEL_H
 #define PANEL_H
 
+#include <Qt>
+
 #include <vector>
 #include <string>
 
@@ -66,11 +68,7 @@ public:
     /** direction for writing the label */
     CVector3d direction;
 
-    /** function for rotating a label. */
-    CPanelLabel rotate( const CPoint3d &, const CMatrix & ) const;
-
-    /** operator to translate a label */
-    CPanelLabel operator+ (const CVector3d &) const;
+    CPanelLabel transformed(const CMatrix4x4 &m) const;
 
     /** operator to copy a label */
     CPanelLabel& operator=( const CPanelLabel &);
@@ -98,11 +96,9 @@ public:
     void fill( const CPoint3d &, const CPoint3d & );
     void fill( const CPoint3d &, const CPoint3d &, const CPoint3d & );
 
-    /** function for rotating a side. */
-    CSide rotate( const CPoint3d &, const CMatrix &) const;
+    CSide transformed(const CMatrix4x4 &m) const;
 
     // operators
-    CSide operator+ (const CVector3d &) const;
     friend ostream& operator<< (ostream &, const CSide &);
 };
 
@@ -179,7 +175,8 @@ public:
 
     void placeLabel();   //  place a label at the center of a panel
     CPanel reframe(enumAlign align) const;
-    CPanel rotate( const CPoint3d &, const CMatrix &) const;
+    CPanel rotated(const CPoint3d &, real angle, Qt::Axis axis) const;
+    CPanel transformed(const CMatrix4x4 &m) const;
     CPanel operator+ (const CVector3d &) const;
     CPanel& operator= (const CPanel &);
 
@@ -191,4 +188,6 @@ ostream& operator<< (ostream &, const CPanel &);
 ostream& operator<< (ostream &, const CSide &);
 ostream& operator<< (ostream &, const CPanelLabel &);
 
+CVector3d rotateNormalized(real angle, const CVector3d &v);
+
 #endif
