@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -114,16 +114,16 @@ void CPanelGroup::plotLabels()
 }
 
 
-/** Rotates a sail around a point.
+/** Transform a sail.
  */
-CPanelGroup CPanelGroup::rotate( const CPoint3d &p, const CMatrix &m ) const
+CPanelGroup CPanelGroup::transformed(const CMatrix4x4 &m) const
 {
     unsigned int i;
     CPanelGroup ret = *this;
     for (i = 0; i < size(); i++)
-        ret[i] = at(i).rotate(p,m);
+        ret[i] = at(i).transformed(m);
     for (i = 0; i < child.size(); i++)
-        ret.child[i] = child[i].rotate(p,m);
+        ret.child[i] = child[i].transformed(m);
     return ret;
 }
 
@@ -144,20 +144,6 @@ CPanelGroup& CPanelGroup::operator=(const CPanelGroup& s)
 }
 
 
-/** Performs a 3D translation of the sail by a given vector.
- */
-CPanelGroup CPanelGroup::operator+(const CVector3d& transl) const
-{
-    unsigned int i;
-    CPanelGroup ret = *this;
-    for (i = 0; i < size(); i++)
-        ret[i] = ret[i] + transl;
-    for (i = 0; i < child.size(); i++)
-        ret.child[i] = ret.child[i] + transl;
-    return ret;
-}
-
-
 /** Outputs a CPanelGroup to a stream.
  */
 ostream& operator<<(ostream &o, const CPanelGroup &s)
