@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,7 @@ CRigDef::CRigDef()
     MCord = 140;
     MWidth = 70;
     MRakeM = 220;
-    MRakeD = atan2(MRakeM, MHeight) * (180 / PI);
+    MRakeD = radiansToDegrees(atan2(MRakeM, MHeight));
     MBase = foreJ - MRakeM * (foreI/MHeight);
     MRnd = 110;
     MRndPos = 50;
