@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -58,8 +58,8 @@ CPanelGroup CRigWorker::makeRig() const
     p0 = mastCenter ( h );
     for (j = 0 ; j < npb ; j++)
     {
-        v1 = CVector3d(cos(PI * real(j) /(npb-1)), 0, sin(PI * real(j) /(npb-1) ) );
-        v1.z() = v1.z() * MWidth / MCord;
+        v1 = CVector3d(cos(M_PI * real(j) /(npb-1)), 0, sin(M_PI * real(j) /(npb-1) ) );
+        v1.setZ(v1.z() * MWidth / MCord);
         mast1.top[j] = p0 + cord * v1;
         mast2.top[j] = p0 - cord *v1;
     }
@@ -73,8 +73,8 @@ CPanelGroup CRigWorker::makeRig() const
 
         for (j = 0 ; j < npb ; j++)
         {
-            v1 = CVector3d(cos(PI * real(j) /(npb-1)), 0, sin(PI * real(j) /(npb-1) ) );
-            v1.z() = v1.z() * MWidth / MCord;
+            v1 = CVector3d(cos(M_PI * real(j) /(npb-1)), 0, sin(M_PI * real(j) /(npb-1) ) );
+            v1.setZ(v1.z() * MWidth / MCord);
             mast1.bottom[j] = mast1.top[j];
             mast2.bottom[j] = mast2.top[j];
             mast1.top[j] = p2 + cord *v1;
@@ -98,8 +98,8 @@ CPanelGroup CRigWorker::makeRig() const
         //printf ("P2 x= %f, y= %f \n", p2.x(), p2.y());
         for (j = 0 ; j < npb ; j++)
         {
-            v1 = CVector3d(cos(PI * real(j) /(npb-1)), sin(PI * real(j) /(npb-1) ), 0 );
-            v1.y() = v1.y() / 2;
+            v1 = CVector3d(cos(M_PI * real(j) /(npb-1)), sin(M_PI * real(j) /(npb-1) ), 0 );
+            v1.setY(v1.y() / 2);
             mast1.bottom[j] = p2 + cord * v1;
             mast1.bottom[j] = mast1.bottom[j] + CVector3d(0 , 0 , -SPW[i]);
             mast1.top[j] = mast1.bottom[j] + CVector3d(0 , 0 , 2*SPW[i]);
@@ -110,7 +110,7 @@ CPanelGroup CRigWorker::makeRig() const
         rig.push_back(mast1);
 
         // make symetrical by rotation
-        mast1 = mast1.rotate(p2 , CMatrix::rot3d(2, PI) );
+        mast1 = mast1.rotated(p2, M_PI, Qt::ZAxis);
 
         rig.push_back(mast1);
     }
@@ -232,10 +232,10 @@ CPoint3d CRigWorker::mastCenter( const real &HM ) const
     // printf ("i= %d, MRnd = %f \n", i, round);
 
     // straight mast section center point
-    p1 = p0 + HM * vm.unit();
+    p1 = p0 + HM * vm.normalized();
 
     // displace center point of section by round
-    p1 = p1 + CMatrix::rot3d( 2, PI/2 ) * vm.unit() * round;
+    p1 = p1 + rotateNormalized(M_PI/2, vm) * round;
     //
     return p1;
 }
