@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,19 +28,37 @@
 /** Constructs a generic view area for a sail.
  */
 CSailDisp::CSailDisp()
+    : m_azimuth(0)
+    , m_elevation(0)
 {
     // initialise data
-    m = CMatrix::id(3);
     drawLabels = false;
-    zoom = 0.8;
+    m_zoom = 0.8;
 }
 
 
-/** Rotates local copy of the object by a given azimuth and elevation.
+/** Returns a rotated copy of the object by a given azimuth and elevation.
  */
-void CSailDisp::calcDispObject()
+CPanelGroup CSailDisp::dispObject() const
 {
-    dispObject = baseObject.rotate( baseRect.center(), m );
+    const CVector3d center = baseRect.center();
+
+    CMatrix4x4 matrix;
+    matrix.translate(center);
+    matrix.rotate(degreesToRadians(m_elevation), CVector3d(1, 0, 0));
+    matrix.rotate(degreesToRadians(m_azimuth), CVector3d(0, 1, 0));
+    matrix.translate(-center);
+
+    return baseObject.transformed(matrix);
+}
+
+
+/**
+ * Accessor for the logical viewport rectangle.
+ */
+CRect3d CSailDisp::logicalRect() const
+{
+    return calcLRect(viewRect, baseRect, m_center, m_zoom);
 }
 
 
@@ -48,9 +66,8 @@ void CSailDisp::calcDispObject()
  */
 void CSailDisp::resetZoomCenter()
 {
-    center = baseRect.center();
-    zoom = 0.8;
-    logicalRect = calcLRect(viewRect, baseRect, center, zoom);
+    m_center = baseRect.center();
+    m_zoom = 0.8;
 }
 
 
@@ -60,33 +77,48 @@ CPoint3d CSailDisp::screenToLogical( const int x, const int y ) const
 {
     // avoid division by zero
     if ((viewRect.width()==0)||(viewRect.height()==0))
-        return center;
+        return m_center;
 
-    return center + CVector3d( logicalRect.width() * ( real(x) / viewRect.width() - 0.5 ),
-                               logicalRect.height() * ( 0.5 - real(y) / viewRect.height() ), 0);
+    const CRect3d logicalRect = this->logicalRect();
+    return m_center + CVector3d( logicalRect.width() * ( real(x) / viewRect.width() - 0.5 ),
+                                 logicalRect.height() * ( 0.5 - real(y) / viewRect.height() ), 0);
 }
 
 
-/** Sets the azimuth and elevation view angles.
+/** Sets the azimuth view angle.
  *
  * @param azimuth azimuth in degrees
- * @param elevation elevation in degrees
  */
-void CSailDisp::setAngle( real azimuth, real elevation )
+void CSailDisp::setAzimuth(real azimuth)
 {
-    m = CMatrix::rot3d(0, PI/180*elevation) * CMatrix::rot3d(1, PI/180*azimuth);
-    calcDispObject();
+    m_azimuth = azimuth;
 }
 
 
-/** Sets the center of the display.
+/** Returns the center of the display in logical coordinates.
+ */
+CPoint3d CSailDisp::center() const
+{
+    return m_center;
+}
+
+
+/** Sets the center of the display in logical coordinates.
  *
  * @param newCenter the new center
  */
-void CSailDisp::setCenter( CPoint3d newCenter )
+void CSailDisp::setCenter(const CPoint3d &center)
 {
-    center = newCenter;
-    logicalRect = calcLRect(viewRect, baseRect, center, zoom);
+    m_center = center;
+}
+
+/** Sets the elevation view angle.
+ *
+ * @param elevation elevation in degrees
+ */
+void CSailDisp::setElevation(real elevation)
+{
+    m_elevation = elevation;
 }
 
 
@@ -100,13 +132,10 @@ void CSailDisp::setObject( const CPanelGroup &obj )
 
     // handle case where the bounding rectangle is flat
     if (baseRect.height() == 0)
-        baseRect.max.y() += 1;
+        baseRect.max.setY(baseRect.max.y() + 1);
     if (baseRect.width() == 0)
-        baseRect.max.x() += 1;
-    center = baseRect.center();
-
-    calcDispObject();
-    logicalRect = calcLRect(viewRect, baseRect, center, zoom);
+        baseRect.max.setX(baseRect.max.x() + 1);
+    m_center = baseRect.center();
 }
 
 
@@ -115,18 +144,24 @@ void CSailDisp::setObject( const CPanelGroup &obj )
 void CSailDisp::setViewRect( const CRect3d &rect )
 {
     viewRect = rect;
-    logicalRect = calcLRect(viewRect, baseRect, center, zoom);
+}
+
+
+/** Returns the zoom factor.
+ */
+real CSailDisp::zoom() const
+{
+    return m_zoom;
 }
 
 
 /** Sets the zoom factor
  *
- * @param newZoom
+ * @param zoom
  */
-void CSailDisp::setZoom(real newZoom)
+void CSailDisp::setZoom(real zoom)
 {
-    zoom = newZoom;
-    logicalRect = calcLRect(viewRect, baseRect, center, zoom);
+    m_zoom = zoom;
 }
 
 
@@ -134,7 +169,7 @@ void CSailDisp::setZoom(real newZoom)
  */
 void CSailDisp::zoomIn()
 {
-    setZoom(zoom * 2);
+    setZoom(m_zoom * 2);
 }
 
 
@@ -142,5 +177,5 @@ void CSailDisp::zoomIn()
  */
 void CSailDisp::zoomOut()
 {
-    setZoom(zoom / 2);
+    setZoom(m_zoom / 2);
 }
