@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -40,46 +40,41 @@ public:
     ;
 
     /** Acessor for the logical viewport rectangle */
-    virtual const CRect3d& getLogicalRect() const
-    {
-        return logicalRect;
-    };
 
     /** Redraw the view. */
-    virtual void redraw()
-    {}
-    ;
+    virtual void redraw() = 0;
     virtual void resetZoomCenter( void );
     virtual CPoint3d screenToLogical( const int x, const int y ) const;
-    virtual void setAngle( real azimuth, real elevation );
-    virtual void setCenter( CPoint3d newCenter );
-    virtual void setObject( const CPanelGroup &objs );
-    virtual void setViewRect( const CRect3d &rect );
-    virtual void setZoom(real newZoom);
-    virtual void zoomIn();
-    virtual void zoomOut();
+
+    void setAzimuth(real azimuth);
+    void setElevation(real elevation);
+
+    CPoint3d center() const;
+    void setCenter(const CPoint3d &newCenter);
+
+    void setObject( const CPanelGroup &objs );
+    void setViewRect( const CRect3d &rect );
+
+    real zoom() const;
+    void setZoom(real newZoom);
+
+    void zoomIn();
+    void zoomOut();
 
     /** Should labels be drawn ? */
     bool drawLabels;
 
-private:
-    void calcDispObject();
-
 protected:
-    /** Rotated copy of the objects */
-    CPanelGroup dispObject;
-
-    /** The center of the viewing area, in logical coordinates */
-    CPoint3d center;
-
-    /** The zoom factor for the view */
-    real zoom;
+    CPanelGroup dispObject() const;
+    CRect3d logicalRect() const;
 
 private:
-    /** Rotation matrix for the view */
-    CMatrix m;
-    /** Viewport rectangle, in logical coordinates */
-    CRect3d logicalRect;
+    real m_azimuth;
+    /** The center of the viewing area, in logical coordinates */
+    CPoint3d m_center;
+    real m_elevation;
+    real m_zoom;
+
     /** Viewport rectangle, in device coordinates */
     CRect3d viewRect;
     /** Bounding rectangle of the unrotated object */
