@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -211,13 +211,12 @@ void CSailDoc::get
 void CSailDoc::get
 ( const QDomNode &parent, CPoint3d &p, const QString &name )
 {
+    real x, y, z;
     QDomElement e = findElement( parent, "CPoint3d", name);
-    get
-    (e, p.x(), "x");
-    get
-    (e, p.y(), "y");
-    get
-    (e, p.z(), "z");
+    get(e, x, "x");
+    get(e, y, "y");
+    get(e, z, "z");
+    p = CPoint3d(x, y, z);
 }
 
 
@@ -611,8 +610,6 @@ void CSailDoc::get
     {
         get(e, p.language, "language");
         get_vector(e, p.mruDocuments, "mruDocuments");
-        get(e, p.helpWindowHeight, "helpWindowHeight");
-        get(e, p.helpWindowWidth, "helpWindowWidth");
         get(e, p.mainWindowHeight, "mainWindowHeight");
         get(e, p.mainWindowWidth, "mainWindowWidth");
     }
@@ -1066,8 +1063,6 @@ void CSailDoc::put(QDomNode &parent, const CPrefs& p, const QString& name)
 
     put(e, p.language, "language");
     put_vector(e, p.mruDocuments, "mruDocuments");
-    put(e, p.helpWindowHeight, "helpWindowHeight");
-    put(e, p.helpWindowWidth, "helpWindowWidth");
     put(e, p.mainWindowHeight, "mainWindowHeight");
     put(e, p.mainWindowWidth, "mainWindowWidth");
 }
