@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,13 @@
 #include "sailcpp/sailcalc.h"
 
 
+double CPrinter::scaleToFit(QPaintDevice* device) const
+{
+    Q_UNUSED(device);
+    return -1;
+}
+
+
 /** Print the current sail data sheet.
  *
  * @param painter
@@ -35,6 +42,8 @@
  */
 void CSailDataPrinter::print(CTextPainter *painter, int, real scale, real fontsize) const
 {
+    Q_UNUSED(scale);
+
     QString text2=" ", text3=" ";
     painter->setFontSize(fontsize, 1);
     painter->printReset();
@@ -183,7 +192,7 @@ void CSailDevelPrinter::print(CTextPainter *painter, int page, real scale, real
     painter->setPenColor(Qt::green);
     CRect3d rp = sail[page].boundingRect();
     painter->drawCross(rp.min, painter->fontMetrics().height() );
-    painter->drawCoord(rp.min, PI );
+    painter->drawCoord(rp.min, M_PI );
     painter->setPen(oldPen);
 
     /* NOTE scale factor on preview screen is not same value as in spinbox
