@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,6 +20,7 @@
 #include "sailviewer-panel.h"
 #include "sailcpp/panelgroup.h"
 
+#include <QApplication>
 #include <QGroupBox>
 #include <QLabel>
 #include <QLayout>
@@ -101,7 +102,9 @@ CSailViewerPanel::CSailViewerPanel(QWidget *parent, enumViewMode viewMode, bool
     layout->addLayout( vbox );
 
 
-    /* set language and size */
+    /* set language */
+    connect(qApp, SIGNAL(languageChanged()),
+            this, SLOT(languageChange()));
     languageChange();
 
     /* connect signals */
