@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -42,10 +42,12 @@ public:
 
     // slots
 public slots:
-    virtual void languageChange();
     virtual void slotAzimuth(real azimuth);
     virtual void slotElevation(real azimuth);
 
+private slots:
+    void languageChange();
+
     // member variables
 protected:
     /** groupbox for parameters */
