@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,6 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#include <QApplication>
+
 #include "sailviewer-panel.h"
 #include "sailviewer-tabs.h"
 
@@ -30,6 +32,11 @@ CSailViewerTabs::CSailViewerTabs(QWidget *parent)
 {
     addViewer(new CSailViewerPanel(NULL, SHADED, true));
     addViewer(new CSailViewerPanel(NULL, WIREFRAME, true));
+
+    // set language
+    connect(qApp, SIGNAL(languageChanged()),
+            this, SLOT(languageChange()));
+    languageChange();
 }
 
 
@@ -52,8 +59,6 @@ void CSailViewerTabs::addViewer(CSailViewerPanel *viewer)
 void CSailViewerTabs::languageChange()
 {
     int tabidx = 0;
-    for (unsigned int i = 0; i < panel.size(); i++)
-        panel[i]->languageChange();
     setTabText(tabidx++, tr("shaded view"));
     setTabText(tabidx++, tr("wireframe view"));
 }
