@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,8 +34,8 @@ public:
     void addViewer(CSailViewerPanel *viewer);
     void setObject(const CPanelGroup &obj);
 
-public slots:
-    virtual void languageChange();
+private slots:
+    void languageChange();
 
 public:
     /** the widgets of each view */
