@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="1.1" language="fr">
+<defaultcodec></defaultcodec>
 <context>
     <name>CBoatElementWidget</name>
     <message>
-        <location filename="" line="0"/>
         <source>Sail information</source>
         <translation type="obsolete">Informations sur la voile</translation>
     </message>
@@ -41,12 +41,10 @@
 <context>
     <name>CFileIO</name>
     <message>
-        <location filename="" line="0"/>
         <source>Open</source>
         <translation type="obsolete">Ouvrir</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Save</source>
         <translation type="obsolete">Enregistrer</translation>
     </message>
@@ -173,7 +171,6 @@
         <translation>Largeur maximum</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Bottom dead rise angle</source>
         <translation type="obsolete">Angle du fond</translation>
     </message>
@@ -198,7 +195,6 @@
         <translation>Position de la largeur maximum</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Side slope angle</source>
         <translation type="obsolete">Inclinaison latérale</translation>
     </message>
@@ -243,7 +239,6 @@
         <translation>Hauteur avant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Side Planks</source>
         <translation type="obsolete">Bordés</translation>
     </message>
@@ -371,17 +366,14 @@
 <context>
     <name>CFormMain</name>
     <message>
-        <location filename="" line="0"/>
         <source>to &amp;DXF</source>
         <translation type="obsolete">&amp;DXF</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>to &amp;TXT sail</source>
         <translation type="obsolete">voile &amp;TXT</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>to &amp;XML sail</source>
         <translation type="obsolete">voile &amp;XML</translation>
     </message>
@@ -411,22 +403,18 @@
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;Dimensions</source>
         <translation type="obsolete">&amp;Dimensions</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;Mould</source>
         <translation type="obsolete">&amp;Moule</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;Patches</source>
         <translation type="obsolete">&amp;Renforts</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;Rig</source>
         <translation type="obsolete">&amp;Gréement</translation>
     </message>
@@ -451,12 +439,10 @@
         <translation>A propos de Sailcut CAD</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>error</source>
         <translation type="obsolete">erreur</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>There was an error writing to the selected file</source>
         <translation type="obsolete">Une erreur s&apos;est produite lors de l&apos;écriture du fichier</translation>
     </message>
@@ -471,37 +457,30 @@
         <translation>A propos de &amp;Sailcut CAD</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>to &amp;Carlson plotter</source>
         <translation type="obsolete">table traçante &amp;Carlson</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>shaded view</source>
         <translation type="obsolete">vue rendu 3D</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>wireframe view</source>
         <translation type="obsolete">vue fil de fer</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>development</source>
         <translation type="obsolete">développement</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>created new sail</source>
         <translation type="obsolete">nouvelle voile créée</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>E&amp;xport 3D sail</source>
         <translation type="obsolete">E&amp;xport voile 3D</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Export &amp;development</source>
         <translation type="obsolete">Export &amp;développement</translation>
     </message>
@@ -531,282 +510,226 @@
         <translation>écrit &apos;%1&apos;</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>There was a data printing error</source>
         <translation type="obsolete">Erreur lors de l&apos;impression des données</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>There was a development printing error</source>
         <translation type="obsolete">Erreur lors de l&apos;impression du développement</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>There was a drawing printing error</source>
         <translation type="obsolete">Erreur lors de l&apos;impression du dessin</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>data</source>
         <translation type="obsolete">données</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>drawing</source>
         <translation type="obsolete">dessin</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>develop</source>
         <translation type="obsolete">développement</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;Print</source>
         <translation type="obsolete">&amp;Imprimer</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail type</source>
         <translation type="obsolete">Type de voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mainsail</source>
         <translation type="obsolete">Grand-voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Jib</source>
         <translation type="obsolete">Foc</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail layout</source>
         <translation type="obsolete">Type de coupe</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Cross Cut</source>
         <translation type="obsolete">Coupe transverse</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Horizontal Cut</source>
         <translation type="obsolete">Coupe horizontale</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Radial Cut</source>
         <translation type="obsolete">Coupe radiale</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Twist Foot Cut</source>
         <translation type="obsolete">Coupe twist Foot</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Vertical Cut</source>
         <translation type="obsolete">Coupe verticale</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mitre Cut</source>
         <translation type="obsolete">Coupe à mitre</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source> sections,   </source>
         <translation type="obsolete">sections,    </translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source> head gores.</source>
         <translation type="obsolete">fuseaux de tête.</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Rig </source>
         <translation type="obsolete">Gréement</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Boat LOA</source>
         <translation type="obsolete">Longueur du bateau</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Fore triangle hoist I</source>
         <translation type="obsolete">Hauteur I du triangle avant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Fore triangle base J</source>
         <translation type="obsolete">Base J du triangle avant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Tack position X</source>
         <translation type="obsolete">Position X de l&apos;amure</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Tack height Y</source>
         <translation type="obsolete">Hauteur Y de l&apos;amure</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail dimensions</source>
         <translation type="obsolete">Dimensions de la voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Luff length</source>
         <translation type="obsolete">Longueur guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mast rake</source>
         <translation type="obsolete">Quête du mat</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Gaff angle wrt luff</source>
         <translation type="obsolete">Angle vergue / guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Gaff length</source>
         <translation type="obsolete">Longueur vergue</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Foot length</source>
         <translation type="obsolete">Longueur bordure</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Leech length</source>
         <translation type="obsolete">Longueur chute</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Shape of edges</source>
         <translation type="obsolete">Forme des bords</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Luff round</source>
         <translation type="obsolete">Rond du guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Gaff round</source>
         <translation type="obsolete">Rond de la vergue</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Leech round</source>
         <translation type="obsolete">Rond de la chute</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Foot round</source>
         <translation type="obsolete">Rond de la bordure</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Luff round position</source>
         <translation type="obsolete">Position du rond de guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Gaff round position</source>
         <translation type="obsolete">Position du rond de la gaffe</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Leech round position</source>
         <translation type="obsolete">Position du rond de chute</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Foot round position</source>
         <translation type="obsolete">Position du rond de bordure</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail settings</source>
         <translation type="obsolete">Réglage de la voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Twist angle</source>
         <translation type="obsolete">Angle de vrillage</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sheeting angle</source>
         <translation type="obsolete">Angle d&apos;ouverture</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Cloth seams and hems</source>
         <translation type="obsolete">Tissu, coutures et ourlets</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Cloth width</source>
         <translation type="obsolete">Largeur du tissu</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Seams width</source>
         <translation type="obsolete">Largeur des coutures</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Leech hem width</source>
         <translation type="obsolete">Largeur pour ourlet chute</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Other hem width</source>
         <translation type="obsolete">Largeur pour autres ourlets</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail mould</source>
         <translation type="obsolete">Moule de voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Luff factor</source>
         <translation type="obsolete">Forme guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Depth</source>
         <translation type="obsolete">Creux</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Leech factor</source>
         <translation type="obsolete">Forme chute</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Top profile</source>
         <translation type="obsolete">Profil supérieur</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mid profile at h = </source>
         <translation type="obsolete">Profil médian à h =</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Bottom profile</source>
         <translation type="obsolete">Profil inférieur</translation>
     </message>
@@ -816,47 +739,38 @@
         <translation>Langue</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mast/Luff rake</source>
         <translation type="obsolete">Quête du mât / guidant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source> head gores,   </source>
         <translation type="obsolete">fuseaux de tête,</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source> luff gore.</source>
         <translation type="obsolete">fuseau coté guindant.</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Wing</source>
         <translation type="obsolete">Aile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source> luff gores.</source>
         <translation type="obsolete">fuseaux de guindant.</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>E&amp;xport &amp;development</source>
         <translation type="obsolete">E&amp;xport développement</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>to &amp;hand-plotting format</source>
         <translation type="obsolete">format coupe &amp;manuelle</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>deg</source>
         <translation type="obsolete">deg</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>to &amp;Hand-plotting format</source>
         <translation type="obsolete">pour traçage &amp;manuel</translation>
     </message>
@@ -934,7 +848,6 @@
         <translation>Moule de voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;Help</source>
         <translation type="obsolete">&amp;Aide</translation>
     </message>
@@ -988,67 +901,54 @@
 <context>
     <name>CFormRig</name>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;New</source>
         <translation type="obsolete">&amp;Nouveau</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>sail &amp;definition</source>
         <translation type="obsolete">&amp;définition de voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>3D &amp;sail</source>
         <translation type="obsolete">&amp;voile 3D</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;Add sail</source>
         <translation type="obsolete">&amp;Ajouter une voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;Open</source>
         <translation type="obsolete">&amp;Ouvrir</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;Save</source>
         <translation type="obsolete">&amp;Enregistrer</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Save &amp;As</source>
         <translation type="obsolete">Enregistrer &amp;sous</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;Close</source>
         <translation type="obsolete">&amp;Fermer</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>&amp;File</source>
         <translation type="obsolete">&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>error</source>
         <translation type="obsolete">erreur</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>There was an error writing to the selected file</source>
         <translation type="obsolete">Une erreur s&apos;est produite lors de l&apos;écriture du fichier</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Rig</source>
         <translation type="obsolete">Gréement</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Open &amp;recent</source>
         <translation type="obsolete">Ouvrir fichier &amp;récent</translation>
     </message>
@@ -1118,17 +1018,17 @@
     <message>
         <location filename="../formrigdefbase.ui" line="445"/>
         <source>SPH2</source>
-        <translation></translation>
+        <translation>SPH2</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="458"/>
         <source>SPH3</source>
-        <translation></translation>
+        <translation>SPH3</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="471"/>
         <source>SPH1</source>
-        <translation></translation>
+        <translation>SPH1</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="487"/>
@@ -1138,7 +1038,7 @@
     <message>
         <location filename="../formrigdefbase.ui" line="505"/>
         <source>SPW3</source>
-        <translation></translation>
+        <translation>SPW3</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="518"/>
@@ -1148,7 +1048,7 @@
     <message>
         <location filename="../formrigdefbase.ui" line="534"/>
         <source>SPW1</source>
-        <translation></translation>
+        <translation>SPW1</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="547"/>
@@ -1158,7 +1058,7 @@
     <message>
         <location filename="../formrigdefbase.ui" line="563"/>
         <source>SPW2</source>
-        <translation></translation>
+        <translation>SPW2</translation>
     </message>
     <message>
         <location filename="../formrigdefbase.ui" line="576"/>
@@ -1476,7 +1376,6 @@
         <translation>Toutes les dimensions sont en millimetre et les angles en degrés</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Rig ID</source>
         <translation type="obsolete">Identification du gréement</translation>
     </message>
@@ -1569,22 +1468,18 @@
         <translation>&amp;Renforts</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>error</source>
         <translation type="obsolete">erreur</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>There was a data printing error</source>
         <translation type="obsolete">Erreur lors de l&apos;impression des données</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>There was a development printing error</source>
         <translation type="obsolete">Erreur lors de l&apos;impression du développement</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>There was a drawing printing error</source>
         <translation type="obsolete">Erreur lors de l&apos;impression du dessin</translation>
     </message>
@@ -1627,7 +1522,6 @@
         <translation>pic</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>IRC width measurements</source>
         <translation type="obsolete">Largeurs mesurées IRC</translation>
     </message>
@@ -1755,7 +1649,6 @@
         <translation>Longueur du bateau</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mast / Luff rake</source>
         <translation type="obsolete">Quête du mât / guidant</translation>
     </message>
@@ -1870,7 +1763,6 @@
         <translation>Ouverture de la voile</translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="" line="0"/>
         <source>m²</source>
         <translation type="obsolete">m²</translation>
     </message>
@@ -1890,7 +1782,6 @@
         <translation>Calculer</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail ID</source>
         <translation type="obsolete">Identification de la voile</translation>
     </message>
@@ -1943,42 +1834,34 @@
 <context>
     <name>CRigSailWidget</name>
     <message>
-        <location filename="" line="0"/>
         <source>Sail information</source>
         <translation type="obsolete">Informations sur la voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>file</source>
         <translation type="obsolete">fichier</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>name</source>
         <translation type="obsolete">nom</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Remove</source>
         <translation type="obsolete">Retirer</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Update</source>
         <translation type="obsolete">Mettre a jour</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Reload</source>
         <translation type="obsolete">Recharger</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>error</source>
         <translation type="obsolete">erreur</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>There was an error reading from the selected file.</source>
         <translation type="obsolete">Une erreur s&apos;est produite lors de la lecture du fichier sélectionné.</translation>
     </message>
@@ -2081,7 +1964,6 @@
         <translation>Longueur du bateau</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mast/Luff rake</source>
         <translation type="obsolete">Quête du mât / guidant</translation>
     </message>
@@ -2271,13 +2153,12 @@
     <message>
         <location filename="../sailprinter.cpp" line="190"/>
         <source>Scale</source>
-        <translation type="unfinished">Echelle</translation>
+        <translation>Echelle</translation>
     </message>
 </context>
 <context>
     <name>CSailDispGL</name>
     <message>
-        <location filename="" line="0"/>
         <source>This system has no OpenGL support.</source>
         <translation type="obsolete">OpenGL n&apos;est pas disponible sur cette machine.</translation>
     </message>
@@ -2287,273 +2168,220 @@
     <message>
         <location filename="../sailprinter.cpp" line="221"/>
         <source>Scale</source>
-        <translation type="unfinished">Echelle</translation>
+        <translation>Echelle</translation>
     </message>
 </context>
 <context>
     <name>CSailPrinter</name>
     <message>
-        <location filename="" line="0"/>
         <source>Sailcut CAD data sheet</source>
         <translation type="obsolete">Données Sailcut CAD</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mainsail</source>
         <translation type="obsolete">Grand-voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Jib</source>
         <translation type="obsolete">Foc</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Wing</source>
         <translation type="obsolete">Aile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>deg</source>
         <translation type="obsolete">deg</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail type</source>
         <translation type="obsolete">Type de voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Cross Cut</source>
         <translation type="obsolete">Coupe transverse</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Horizontal Cut</source>
         <translation type="obsolete">Coupe horizontale</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Radial Cut</source>
         <translation type="obsolete">Coupe radiale</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>sections</source>
         <translation type="obsolete">sections</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>head gores</source>
         <translation type="obsolete">fuseaux de tête</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>luff gores</source>
         <translation type="obsolete">fuseaux de guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Twist Foot Cut</source>
         <translation type="obsolete">Coupe twist foot</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Vertical Cut</source>
         <translation type="obsolete">Coupe verticale</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mitre Cut</source>
         <translation type="obsolete">Coupe à mitre</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail layout</source>
         <translation type="obsolete">Type de coupe</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Rig</source>
         <translation type="obsolete">Gréement</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Boat LOA</source>
         <translation type="obsolete">Longueur du bateau</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mast/Luff rake</source>
         <translation type="obsolete">Quête du mât / guidant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Tack position X</source>
         <translation type="obsolete">Position X de l&apos;amure</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Tack height Y</source>
         <translation type="obsolete">Hauteur Y de l&apos;amure</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Fore triangle hoist I</source>
         <translation type="obsolete">Hauteur I du triangle avant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Fore triangle base J</source>
         <translation type="obsolete">Base J du triangle avant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail dimensions</source>
         <translation type="obsolete">Dimensions de la voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Luff length</source>
         <translation type="obsolete">Longueur guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Foot length</source>
         <translation type="obsolete">Longueur bordure</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Leech length</source>
         <translation type="obsolete">Longueur chute</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Gaff length</source>
         <translation type="obsolete">Longueur vergue</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Gaff angle wrt luff</source>
         <translation type="obsolete">Angle vergue / guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Shape of edges</source>
         <translation type="obsolete">Forme des bords</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Luff round</source>
         <translation type="obsolete">Rond du guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Luff round position</source>
         <translation type="obsolete">Position du rond de guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Foot round</source>
         <translation type="obsolete">Rond de la bordure</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Foot round position</source>
         <translation type="obsolete">Position du rond de bordure</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Leech round</source>
         <translation type="obsolete">Rond de la chute</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Leech round position</source>
         <translation type="obsolete">Position du rond de chute</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Gaff round</source>
         <translation type="obsolete">Rond de la vergue</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Gaff round position</source>
         <translation type="obsolete">Position du rond de la gaffe</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail settings</source>
         <translation type="obsolete">Réglage de la voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Twist angle</source>
         <translation type="obsolete">Angle de vrillage</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sheeting angle</source>
         <translation type="obsolete">Ouverture de la voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Cloth seams and hems</source>
         <translation type="obsolete">Tissu, coutures et ourlets</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Cloth width</source>
         <translation type="obsolete">Largeur du tissu</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Seams width</source>
         <translation type="obsolete">Largeur des coutures</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Leech hem width</source>
         <translation type="obsolete">Largeur pour ourlet chute</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Other hem width</source>
         <translation type="obsolete">Largeur pour autres ourlets</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Sail mould</source>
         <translation type="obsolete">Moule de voile</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Luff factor</source>
         <translation type="obsolete">Forme guindant</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Depth</source>
         <translation type="obsolete">Creux</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Leech factor</source>
         <translation type="obsolete">Forme chute</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Top profile</source>
         <translation type="obsolete">Profil supérieur</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Mid profile at h = </source>
         <translation type="obsolete">Profil médian à h =</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>Bottom profile</source>
         <translation type="obsolete">Profil inférieur</translation>
     </message>
@@ -2655,17 +2483,14 @@
 <context>
     <name>Dialog</name>
     <message>
-        <location filename="" line="0"/>
         <source>Dialog</source>
         <translation type="obsolete">Dialogue</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>All panels in a single file</source>
         <translation type="obsolete">Tous les panneaux dans un seul fichier</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>One file per panel</source>
         <translation type="obsolete">Un fichier par panneau</translation>
     </message>
@@ -2673,12 +2498,10 @@
 <context>
     <name>XmlReaderTempl</name>
     <message>
-        <location filename="" line="0"/>
         <source>error</source>
         <translation type="obsolete">erreur</translation>
     </message>
     <message>
-        <location filename="" line="0"/>
         <source>There was an error reading from the selected file.</source>
         <translation type="obsolete">Une erreur s&apos;est produite à la lecture du fichier sélectionné.</translation>
     </message>
