@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2015 Robert & Jeremy Laine
+ * Copyright (C) 1993-2017 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -77,9 +77,11 @@ public:
     CWidgetProfile( QWidget*, CProfile*, QString, CWidgetProfileVert* );
 
 protected slots:
-    virtual void languageChange();
     void slotChanged();
 
+private slots:
+    void languageChange();
+
     // member variables
 public:
     /** label for luff */
